"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.useAdapter = exports.LRUCacheAdapter = void 0;
const core_1 = __importDefault(require("@type-cacheable/core"));
class LRUCacheAdapter {
    constructor(lruClient) {
        this.lruClient = lruClient;
        this.get = this.get.bind(this);
        this.del = this.del.bind(this);
        this.delHash = this.delHash.bind(this);
        this.getClientTTL = this.getClientTTL.bind(this);
        this.keys = this.keys.bind(this);
        this.set = this.set.bind(this);
    }
    get(cacheKey) {
        return __awaiter(this, void 0, void 0, function* () {
            return Promise.resolve(this.lruClient.get(cacheKey));
        });
    }
    set(cacheKey, value, ttl) {
        return __awaiter(this, void 0, void 0, function* () {
            // the lru-cache takes ttl in ms instead of seconds, so convert seconds to ms
            return Promise.resolve(this.lruClient.set(cacheKey, value, ttl ? {
                ttl: ttl * 1000,
            } : undefined));
        });
    }
    getClientTTL() {
        try {
            return this.lruClient.ttl / 1000;
        }
        catch (_a) {
            return 0;
        }
    }
    del(keyOrKeys) {
        return __awaiter(this, void 0, void 0, function* () {
            if (Array.isArray(keyOrKeys)) {
                keyOrKeys.forEach((key) => {
                    this.lruClient.delete(key);
                });
                return keyOrKeys.length;
            }
            this.lruClient.delete(keyOrKeys);
            return 1;
        });
    }
    keys(pattern) {
        return __awaiter(this, void 0, void 0, function* () {
            const allKeys = this.lruClient.keys();
            const regExp = new RegExp(pattern, 'g');
            const matchedKeys = [];
            for (const key of allKeys) {
                if (Array.isArray(key.match(regExp))) {
                    matchedKeys.push(key);
                }
            }
            return matchedKeys;
        });
    }
    delHash(hashKeyOrKeys) {
        return __awaiter(this, void 0, void 0, function* () {
            const finalDeleteKeys = Array.isArray(hashKeyOrKeys)
                ? hashKeyOrKeys
                : [hashKeyOrKeys];
            const deletePromises = finalDeleteKeys.map((key) => this.keys(key).then(this.del));
            yield Promise.all(deletePromises);
            return;
        });
    }
}
exports.LRUCacheAdapter = LRUCacheAdapter;
const useAdapter = (client, asFallback, options) => {
    const lruCacheAdapter = new LRUCacheAdapter(client);
    if (asFallback) {
        core_1.default.setFallbackClient(lruCacheAdapter);
    }
    else {
        core_1.default.setClient(lruCacheAdapter);
    }
    if (options) {
        core_1.default.setOptions(options);
    }
    return lruCacheAdapter;
};
exports.useAdapter = useAdapter;
//# sourceMappingURL=index.js.map